# Changelog

## 0.4.0 - 2026-03-06

- Fix event loop creation for compatibility with Python 3.14.

## 0.3.0 - 2024-09-03

- Add an `--exclude` parameter to avoid retrieving some families of URLs.
- Fix the handling of interruptions (SIGINT, SIGTERM and uncaught exceptions).
- Remove spurious warning when encountering XML instead of HTML.
- Improve error message on network timeout.

## 0.2.0 - 2023-02-16

- Add support for Python 3.11.

## 0.1.3 - 2022-06-30

- Initial release.
